Changelog
=============


All notable changes to this project will be documented here.

`Development`_
---------------

.. note:: Changes noted in this subsection are to be released in the next version.
        If you're keen to check something out before its released, you can use a
        `development install <development.html#development-installation>`__.

`0.0.1`_
--------------

.. _Development: https://github.com/morganjwilliams/pyrolite/compare/0.0.2...develop
.. _0.1.0: https://github.com/morganjwilliams/autopew/compare/0.0.1...0.0.2
